@@ -77,3 +77,37 @@ test_that("create_usrtool: store_res", {
   tool2 <- create_usrtool("xyz", func, store_res = FALSE)[[1]]
   expect_equal(environment(tool2$clone)$private$def_store_res, FALSE)
 })
+
+test_that("create_usrtool: x and y", {
+  tool = create_usrtool("t1", x=c(0,1,2), y=c(0,2,3))[[1]]
+  expect_equal(tool$get_x(), c(0,1,2))
+  expect_equal(tool$get_y(), c(0,2,3))
+})
+
+test_that("usr_wrapper", {
+  testset <- create_testset("curve", "c1")[[1]]
+
+  func <- create_example_func()
+
+  tool1 <- create_usrtool("xyz", func)[[1]]
+  res1 <- environment(tool1$clone)$private$f_wrapper(testset, calc_auc = FALSE,
+                                                     store_res = TRUE)
+
+  expect_equal(res1$x, c(0.00, 0.25, 0.50, 0.75, 1.00))
+  expect_equal(res1$y, c(0.00, 0.25, 0.50, 0.75, 1.00))
+  expect_true(is.na(res1$auc))
+
+  res2 <- environment(tool1$clone)$private$f_wrapper(testset, calc_auc = FALSE,
+                                                     store_res = FALSE)
+  expect_true(is.null(res2))
+
+  res3 <- environment(tool1$clone)$private$f_wrapper(testset, calc_auc = TRUE,
+                                                     store_res = TRUE)
+  expect_equal(res3$x, c(0.00, 0.25, 0.50, 0.75, 1.00))
+  expect_equal(res3$y, c(0.00, 0.25, 0.50, 0.75, 1.00))
+  expect_equal(res3$auc, 0.5)
+
+})
+
+ss = create_usrtool("ss", x=c(0,1,2), y=c(0,2,3))
+
